package com.ruoyi.ibs.list.service.impl;

import java.util.List;

import com.ruoyi.ibs.list.domain.SignedProducts;
import com.ruoyi.ibs.list.mapper.SignedProductsMapper;
import com.ruoyi.ibs.list.service.ISignedProductsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;


/**
 * 个人签约产品Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-11-07
 */
@Service
public class SignedProductsServiceImpl implements ISignedProductsService
{
    @Autowired
    private SignedProductsMapper signedProductsMapper;

    /**
     * 查询个人签约产品
     * 
     * @param currdeposFlag 个人签约产品主键
     * @return 个人签约产品
     */
    @Override
    public SignedProducts selectSignedProductsByCurrdeposFlag(String currdeposFlag)
    {
        return signedProductsMapper.selectSignedProductsByCurrdeposFlag(currdeposFlag);
    }

    /**
     * 查询个人签约产品列表
     * 
     * @param signedProducts 个人签约产品
     * @return 个人签约产品
     */
    @Override
    public List<SignedProducts> selectSignedProductsList(SignedProducts signedProducts)
    {
        return signedProductsMapper.selectSignedProductsList(signedProducts);
    }

    /**
     * 新增个人签约产品
     * 
     * @param signedProducts 个人签约产品
     * @return 结果
     */
    @Override
    public int insertSignedProducts(SignedProducts signedProducts)
    {
        return signedProductsMapper.insertSignedProducts(signedProducts);
    }

    /**
     * 修改个人签约产品
     * 
     * @param signedProducts 个人签约产品
     * @return 结果
     */
    @Override
    public int updateSignedProducts(SignedProducts signedProducts)
    {
        return signedProductsMapper.updateSignedProducts(signedProducts);
    }

    /**
     * 批量删除个人签约产品
     * 
     * @param currdeposFlags 需要删除的个人签约产品主键
     * @return 结果
     */
    @Override
    public int deleteSignedProductsByCurrdeposFlags(String[] currdeposFlags)
    {
        return signedProductsMapper.deleteSignedProductsByCurrdeposFlags(currdeposFlags);
    }

    /**
     * 删除个人签约产品信息
     * 
     * @param currdeposFlag 个人签约产品主键
     * @return 结果
     */
    @Override
    public int deleteSignedProductsByCurrdeposFlag(String currdeposFlag)
    {
        return signedProductsMapper.deleteSignedProductsByCurrdeposFlag(currdeposFlag);
    }
}
